
Keras Embedding Similarity
==========================


.. image:: https://travis-ci.org/CyberZHG/keras-embed-sim.svg
   :target: https://travis-ci.org/CyberZHG/keras-embed-sim
   :alt: Travis


.. image:: https://coveralls.io/repos/github/CyberZHG/keras-embed-sim/badge.svg?branch=master
   :target: https://coveralls.io/github/CyberZHG/keras-embed-sim
   :alt: Coverage

